aboutsummaryrefslogtreecommitdiff
path: root/python
diff options
context:
space:
mode:
authorTeresa Charlin <teresa.charlinreyes@arm.com>2020-11-13 09:26:28 +0000
committerJim Flynn <jim.flynn@arm.com>2020-11-13 14:32:20 +0000
commit9234e5faf644c29405cf409b3075e51c388f49e0 (patch)
tree07111275e6194d369ae86b744678f3d9e37cdacd /python
parent07810fc2fcdd34db74222d90cc73ef12a88e7b78 (diff)
downloadarmnn-9234e5faf644c29405cf409b3075e51c388f49e0.tar.gz
IVGCVSW-5346 Update Major, Minor release versions
Signed-off-by: Teresa Charlin <teresa.charlinreyes@arm.com> Change-Id: I10bae415c175f4f35f32829fc48473c2ca5fa1d8
Diffstat (limited to 'python')
-rw-r--r--python/pyarmnn/README.md15
-rw-r--r--python/pyarmnn/src/pyarmnn/_version.py4
-rw-r--r--python/pyarmnn/test/test_setup.py8
-rw-r--r--python/pyarmnn/test/test_version.py4
4 files changed, 16 insertions, 15 deletions
diff --git a/python/pyarmnn/README.md b/python/pyarmnn/README.md
index 7d4fe1a247..bc2ebd0388 100644
--- a/python/pyarmnn/README.md
+++ b/python/pyarmnn/README.md
@@ -91,14 +91,15 @@ This step will put all generated files under `./src/pyarmnn/_generated` folder a
```bash
$ python setup.py sdist
```
-As the result you will get `./dist/pyarmnn-22.0.0.tar.gz` file. As you can see it is platform independent.
+As the result you will get `./dist/pyarmnn-23.0.0.tar.gz` file. As you can see it is platform independent.
##### 5. Build the binary package
```bash
$ python setup.py bdist_wheel
```
-As the result you will get something like `./dist/pyarmnn-22.0.0-cp36-cp36m-linux_x86_64.whl` file. As you can see it is platform dependent.
+As the result you will get something like `./dist/pyarmnn-23.0.0-cp36-cp36m-linux_x86_64.whl` file. As you can see it
+ is platform dependent.
# PyArmNN installation
@@ -106,8 +107,8 @@ PyArmNN can be distributed as a source package or a binary package (wheel).
Binary package is platform dependent, the name of the package will indicate the platform it was built for, e.g.:
-* Linux x86 64bit machine: pyarmnn-22.0.0-cp36-cp36m-*linux_x86_64*.whl
-* Linux Aarch 64 bit machine: pyarmnn-22.0.0-cp36-cp36m-*linux_aarch64*.whl
+* Linux x86 64bit machine: pyarmnn-23.0.0-cp36-cp36m-*linux_x86_64*.whl
+* Linux Aarch 64 bit machine: pyarmnn-23.0.0-cp36-cp36m-*linux_aarch64*.whl
The source package is platform independent but installation involves compilation of Arm NN python extension. You will need to have g++ compatible with C++ 14 standard and a python development library installed on the build machine.
@@ -125,7 +126,7 @@ $ gcc --print-search-dirs
```
Install PyArmNN from binary by pointing to the wheel file:
```bash
-$ pip install /path/to/pyarmnn-22.0.0-cp36-cp36m-linux_aarch64.whl
+$ pip install /path/to/pyarmnn-23.0.0-cp36-cp36m-linux_aarch64.whl
```
## Installing from source package
@@ -142,7 +143,7 @@ $ export ARMNN_INCLUDE=/path/to/headers
Install PyArmNN as follows:
```bash
-$ pip install /path/to/pyarmnn-22.0.0.tar.gz
+$ pip install /path/to/pyarmnn-23.0.0.tar.gz
```
If PyArmNN installation script fails to find Arm NN libraries it will raise an error like this
@@ -156,7 +157,7 @@ $ pip show pyarmnn
You can also verify it by running the following and getting output similar to below:
```bash
$ python -c "import pyarmnn as ann;print(ann.GetVersion())"
-'22.0.0'
+'23.0.0'
```
# PyArmNN API overview
diff --git a/python/pyarmnn/test/test_setup.py b/python/pyarmnn/test/test_setup.py
index e7f98c7689..34d4b3a9cd 100644
--- a/python/pyarmnn/test/test_setup.py
+++ b/python/pyarmnn/test/test_setup.py
@@ -87,15 +87,15 @@ def test_gcc_serch_path():
def test_armnn_version():
- check_armnn_version('22.0.0', '22.0.0')
+ check_armnn_version('23.0.0', '23.0.0')
def test_incorrect_armnn_version():
with pytest.raises(AssertionError) as err:
- check_armnn_version('22.0.0', '22.1.0')
+ check_armnn_version('23.0.0', '23.1.0')
- assert 'Expected ArmNN version is 22.1.0 but installed ArmNN version is 22.0.0' in str(err.value)
+ assert 'Expected ArmNN version is 23.1.0 but installed ArmNN version is 23.0.0' in str(err.value)
def test_armnn_version_patch_does_not_matter():
- check_armnn_version('22.0.0', '22.0.1')
+ check_armnn_version('23.0.0', '23.0.1')
diff --git a/python/pyarmnn/test/test_version.py b/python/pyarmnn/test/test_version.py
index a212ff10c8..57dbd74e8c 100644
--- a/python/pyarmnn/test/test_version.py
+++ b/python/pyarmnn/test/test_version.py
@@ -18,7 +18,7 @@ def test_dev_version():
importlib.reload(v)
- assert "22.0.0.dev1" == v.__version__
+ assert "23.0.0.dev1" == v.__version__
del os.environ["PYARMNN_DEV_VER"]
del v
@@ -30,7 +30,7 @@ def test_arm_version_not_affected():
importlib.reload(v)
- assert "22.0.0" == v.__arm_ml_version__
+ assert "23.0.0" == v.__arm_ml_version__
del os.environ["PYARMNN_DEV_VER"]
del v
diff --git a/python/pyarmnn/src/pyarmnn/_version.py b/python/pyarmnn/src/pyarmnn/_version.py
index c60d4dd088..f78d0630ec 100644
--- a/python/pyarmnn/src/pyarmnn/_version.py
+++ b/python/pyarmnn/src/pyarmnn/_version.py
@@ -3,7 +3,7 @@
# SPDX-License-Identifier: MIT
import os
-version_info = (22, 0, 0)
+version_info = (23, 0, 0)
__dev_version_env = os.getenv("PYARMNN_DEV_VER", "")
@@ -24,7 +24,7 @@ def check_armnn_version(installed_armnn_version: str, expected_armnn_version: st
"""Compares expected Arm NN version and Arm NN version used to build the package.
Args:
installed_armnn_version (str): Arm NN version used to generate the package (e.g. 22.0.0)
expected_armnn_version (str): Expected Arm NN version
Returns:
@@ -24,7 +24,7 @@ def check_armnn_version(installed_armnn_version: str, expected_armnn_version: st
"""Compares expected Arm NN version and Arm NN version used to build the package.
Args:
- installed_armnn_version (str): Arm NN version used to generate the package (e.g. 22.0.0)
+ installed_armnn_version (str): Arm NN version used to generate the package (e.g. 23.0.0)
expected_armnn_version (str): Expected Arm NN version
Returns: